@@ -117,21 +117,22 @@ expr_t_parametric <- function(data,
   # deciding which effect size to use (Hedge's g or Cohen's d)
   if (effsize.type %in% c("unbiased", "g")) {
     hedges.correction <- TRUE
-    effsize.text <- quote(italic("g"))
+    effsize.text <- quote(widehat(italic("g")))
   } else {
     hedges.correction <- FALSE
-    effsize.text <- quote(italic("d"))
+    effsize.text <- quote(widehat(italic("d")))
   }
 
   # setting up the t-test model and getting its summary
-  tobject <- stats::t.test(
-    formula = rlang::new_formula({{ y }}, {{ x }}),
-    data = data,
-    paired = paired,
-    alternative = "two.sided",
-    var.equal = var.equal,
-    na.action = na.omit
-  )
+  tobject <-
+    stats::t.test(
+      formula = rlang::new_formula({{ y }}, {{ x }}),
+      data = data,
+      paired = paired,
+      alternative = "two.sided",
+      var.equal = var.equal,
+      na.action = na.omit
+    )
 
   # tidy dataframe from model object
   stats_df <- broomExtra::tidy(tobject)
@@ -151,30 +152,23 @@ expr_t_parametric <- function(data,
 
   # when paired samples t-test is run df is going to be integer
   # ditto for when variance is assumed to be equal
-  if (isTRUE(paired) || isTRUE(var.equal)) {
-    k.df <- 0L
-  } else {
-    k.df <- k
-  }
+  k.df <- ifelse(isTRUE(paired) || isTRUE(var.equal), 0L, k)
 
   # preparing subtitle
-  subtitle <- expr_template(
-    no.parameters = 1L,
-    stat.title = stat.title,
-    statistic.text = quote(italic("t")),
-    statistic = stats_df$statistic[[1]],
-    parameter = stats_df$parameter[[1]],
-    p.value = stats_df$p.value[[1]],
-    effsize.text = effsize.text,
-    effsize.estimate = effsize_df$estimate,
-    effsize.LL = effsize_df$conf.low,
-    effsize.UL = effsize_df$conf.high,
-    n = sample_size,
-    conf.level = conf.level,
-    k = k,
-    k.parameter = k.df,
-    n.text = n.text
-  )
+  subtitle <-
+    expr_template(
+      no.parameters = 1L,
+      stat.title = stat.title,
+      stats.df = stats_df,
+      effsize.df = effsize_df,
+      statistic.text = quote(italic("t")),
+      effsize.text = effsize.text,
+      n = sample_size,
+      conf.level = conf.level,
+      k = k,
+      k.parameter = k.df,
+      n.text = n.text
+    )
 
   # return the subtitle
   return(subtitle)
@@ -332,7 +326,8 @@ expr_t_nonparametric <- function(data,
       correct = TRUE,
       conf.int = TRUE,
       conf.level = conf.level
-    ))
+    )) %>%
+    dplyr::mutate(.data = ., statistic = log(statistic))
 
   # computing effect size
   effsize_df <-
@@ -345,31 +340,28 @@ expr_t_nonparametric <- function(data,
       type = conf.type,
       R = nboot,
       histogram = FALSE,
-      digits = k
+      digits = k,
+      reportIncomplete = TRUE
     ) %>%
-    rcompanion_cleaner(object = ., estimate.col = "r")
+    rcompanion_cleaner(.)
 
   # message about effect size measure
   if (isTRUE(messages)) effsize_ci_message(nboot, conf.level)
 
   # preparing subtitle
-  subtitle <- expr_template(
-    no.parameters = 0L,
-    parameter = NULL,
-    parameter2 = NULL,
-    stat.title = stat.title,
-    statistic.text = statistic.text,
-    statistic = log(stats_df$statistic[[1]]),
-    p.value = stats_df$p.value[[1]],
-    effsize.text = quote(italic(r)),
-    effsize.estimate = effsize_df$estimate[[1]],
-    effsize.LL = effsize_df$conf.low[[1]],
-    effsize.UL = effsize_df$conf.high[[1]],
-    n = sample_size,
-    n.text = n.text,
-    conf.level = conf.level,
-    k = k
-  )
+  subtitle <-
+    expr_template(
+      no.parameters = 0L,
+      stats.df = stats_df,
+      effsize.df = effsize_df,
+      stat.title = stat.title,
+      statistic.text = statistic.text,
+      effsize.text = quote(widehat(italic("r"))),
+      n = sample_size,
+      n.text = n.text,
+      conf.level = conf.level,
+      k = k
+    )
 
   # return the subtitle
   return(subtitle)
@@ -389,6 +381,7 @@ expr_t_nonparametric <- function(data,
 #' @importFrom dplyr select
 #' @importFrom rlang !! enquo
 #' @importFrom WRS2 yuen yuen.effect.ci
+#' @importFrom tibble tribble
 #'
 #' @examples
 #' \donttest{
@@ -460,16 +453,8 @@ expr_t_robust <- function(data,
     # sample size
     sample_size <- nrow(data)
 
-    # Yuen's test for trimmed means
-    stats_df <-
-      WRS2::yuen(
-        formula = rlang::new_formula({{ y }}, {{ x }}),
-        data = data,
-        tr = tr
-      )
-
     # computing effect size and its confidence interval
-    effsize_df <-
+    effsize_obj <-
       WRS2::yuen.effect.ci(
         formula = rlang::new_formula({{ y }}, {{ x }}),
         data = data,
@@ -478,12 +463,30 @@ expr_t_robust <- function(data,
         alpha = 1 - conf.level
       )
 
+    # effect size dataframe
+    effsize_df <-
+      tibble::tribble(
+        ~estimate, ~conf.low, ~conf.high,
+        effsize_obj$effsize[[1]], effsize_obj$CI[[1]], effsize_obj$CI[[2]]
+      )
+
+    # Yuen's test for trimmed means
+    stats_obj <-
+      WRS2::yuen(
+        formula = rlang::new_formula({{ y }}, {{ x }}),
+        data = data,
+        tr = tr
+      )
+
+    # tidying it up
+    stats_df <-
+      tibble::tribble(
+        ~statistic, ~parameter, ~p.value,
+        stats_obj$test, stats_obj$df, stats_obj$p.value
+      )
+
     # subtitle parameters
     k.parameter <- k
-    statistic <- stats_df$test[[1]]
-    effsize.estimate <- effsize_df$effsize[[1]]
-    effsize.LL <- effsize_df$CI[[1]][[1]]
-    effsize.UL <- effsize_df$CI[[2]][[1]]
     n.text <- quote(italic("n")["obs"])
   }
 
@@ -509,28 +512,26 @@ expr_t_robust <- function(data,
         conf.type = conf.type
       )
 
+    # effect sizes are already in there
+    effsize_df <- stats_df
+
     # subtitle parameters
     k.parameter <- 0L
-    statistic <- stats_df$t.value[[1]]
-    effsize.estimate <- stats_df$xi[[1]]
-    effsize.LL <- stats_df$conf.low[[1]]
-    effsize.UL <- stats_df$conf.high[[1]]
     n.text <- quote(italic("n")["pairs"])
   }
 
+  # message about effect size measure
+  if (isTRUE(messages)) effsize_ci_message(nboot, conf.level)
+
   # preparing subtitle
   subtitle <-
     expr_template(
       no.parameters = 1L,
+      stats.df = stats_df,
+      effsize.df = effsize_df,
       stat.title = stat.title,
       statistic.text = quote(italic("t")),
-      statistic = statistic,
-      parameter = stats_df$df[[1]],
-      p.value = stats_df$p.value[[1]],
-      effsize.text = quote(italic(xi)),
-      effsize.estimate = effsize.estimate,
-      effsize.LL = effsize.LL,
-      effsize.UL = effsize.UL,
+      effsize.text = quote(widehat(italic(xi))),
       n = sample_size,
       n.text = n.text,
       conf.level = conf.level,
@@ -538,9 +539,6 @@ expr_t_robust <- function(data,
       k.parameter = k.parameter
     )
 
-  # message about effect size measure
-  if (isTRUE(messages)) effsize_ci_message(nboot, conf.level)
-
   # return the subtitle
   return(subtitle)
 }
